==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_StoryArchive.pm <==
package WebGUI::i18n::German::Asset_StoryArchive;
use utf8;
our $I18N = {
  'add a story' => {
    'lastUpdated' => '1252336742',
    'message' => 'Bericht hinzufügen'
  },
  'addStoryUrl' => {
    'lastUpdated' => '1252336767',
    'message' => 'URL mit dem der Benutzer einen Bericht hinzufügen kann'
  },
  'approval workflow' => {
    'lastUpdated' => '1252336775',
    'message' => 'Story Approval Workflow'
  },
  'approval workflow help' => {
    'lastUpdated' => '1252336823',
    'message' => 'Wählen Sie einen Workflow, der auf jeden Bericht angewandt wird, wenn er gespeichert wird.'
  },
  'approvalWorkflowId' => {
    'lastUpdated' => '1252336857',
    'message' => 'Die GUID des Workflows, der auf jeden Bericht angewandt wird, wenn er gespeichert wird.'
  },
  'archive after' => {
    'lastUpdated' => '1252336868',
    'message' => 'Berichte archivieren nach'
  },
  'archive after help' => {
    'lastUpdated' => '1252336936',
    'message' => 'Nach dieser Zeit werden Berichtsassets archiviert und sind nicht mehr in der Berichtsliste oder den Feeds sichtbar. Die Archivierung kann mit 0 abgeschaltet werden.'
  },
  'archiveAfter' => {
    'lastUpdated' => '1252336972',
    'message' => 'Zeit in Sekunden. Nach dieser Zeit wird der Bericht archiviert. '
  },
  'asset title' => {
    'lastUpdated' => '1252336980',
    'message' => 'Titel des Assets'
  },
  'asset url' => {
    'lastUpdated' => '1252336987',
    'message' => 'URL des Assets'
  },
  'assetName' => {
    'lastUpdated' => '1250973574',
    'message' => 'Berichtsarchiv'
  },
  'asset_loop' => {
    'lastUpdated' => '1252337037',
    'message' => 'Schleife, die die ersten bis zu 50 Assets enthält, auf die das Schlüsselwort zutrifft.'
  },
  'atomUrl' => {
    'lastUpdated' => '1252337053',
    'message' => 'URL zum Atom-Feed für dieses Berichtsarchiv'
  },
  'canPostStories' => {
    'lastUpdated' => '1252337078',
    'message' => 'Ein boolscher Wert der wahr ist, wenn der Nutzer Berichte verfassen darf.'
  },
  'creationDate' => {
    'lastUpdated' => '1252337119',
    'message' => 'Datum als Epochangabe, an dem der Bericht erstellt oder ins Berichtarchiv augenommen wurde.'
  },
  'date_loop' => {
    'lastUpdated' => '1252337184',
    'message' => 'Eine Schleife, die Berichte an ihren Erstellungsdatum enthält mit Unterschleifen für jeden Tag. Die Schleife hat Seitenumbrüche.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1252337234',
    'message' => 'Icon um den Bericht zu löschen. Hat der Nutzer keine Löschberechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'edit story template' => {
    'lastUpdated' => '1252337250',
    'message' => 'Template Bericht bearbeiten'
  },
  'edit story template help' => {
    'lastUpdated' => '1252337286',
    'message' => 'Template um ein Berichtsasset hinzuzufügen oder zu bearbeiten.'
  },
  'editIcon' => {
    'lastUpdated' => '1252337310',
    'message' => 'Icon um den Bericht zu bearbeiten. Hat der Nutzer keine Bearbeiten-Berechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'editStoryTemplateId' => {
    'lastUpdated' => '1252337364',
    'message' => 'GUID des Templates mit dem Berichtsassets hinzugefügt oder bearbeitet werden.'
  },
  'epochDate' => {
    'lastUpdated' => '1252337428',
    'message' => 'Epoch-Angabe für den Tagesbeginn des Tages an dem die Berichte dem Berichtsarchiv hinzugefügt wurden.'
  },
  'group to post' => {
    'lastUpdated' => '1252337445',
    'message' => 'Gruppe die verfasst'
  },
  'group to post help' => {
    'lastUpdated' => '1252337468',
    'message' => 'Gruppe die Berichte zu diesem Berichtsarchiv hinzufügen darf.'
  },
  'groupToPost' => {
    'lastUpdated' => '1252337493',
    'message' => 'GUID der Gruppe die Berichte zum Berichtsarchiv hinzufügen darf.'
  },
  'keyword' => {
    'lastUpdated' => '1252337511',
    'message' => 'Schlüsselwort dieser Assetliste'
  },
  'keyword list template' => {
    'lastUpdated' => '1252337539',
    'message' => 'Berichtsarchiv Template Schlüsselwortliste'
  },
  'keyword list template help' => {
    'lastUpdated' => '1252337612',
    'message' => 'Das Template um die Assetliste anzuzeigen, auf die ein Schlüsselwort zutrifft wenn das Berichtsarchiv exportiert wird.'
  },
  'keywordCloud' => {
    'lastUpdated' => '1252337648',
    'message' => 'Die Tag-Wolke der Schlüsselworte in diesem Berichtsarchiv'
  },
  'keywordListTemplateId' => {
    'lastUpdated' => '1252337748',
    'message' => 'GUID des Templates um die Assetliste anzuzeigen, auf die ein Schlüsselwort zutrifft wenn das Berichtsarchiv exportiert wird.'
  },
  'photo width' => {
    'lastUpdated' => '1252337759',
    'message' => 'Photobreite'
  },
  'photo width help' => {
    'lastUpdated' => '1252337953',
    'message' => 'Photos die vom YUI Carousel angezeigt werden müssen für eine korrekte Darstellung die selbe Größe haben. Auf diese Breite werden alle Photos skaliert. Um dieses Feature auszuschalten die Breite auf 0 setzen.'
  },
  'photoWidth' => {
    'lastUpdated' => '1252337842',
    'message' => 'Die Breite auf die alle Photos, die zu Berichten in diesem Berichtsarchiv hochgeladen werden, skaliert werden'
  },
  'rich editor' => {
    'lastUpdated' => '1252337959',
    'message' => 'Rich Editor'
  },
  'rich editor help' => {
    'lastUpdated' => '1252337987',
    'message' => 'Der WYSIWIG-Editor mit dem der Berichtsinhalt bearbeitet wird.'
  },
  'richEditorId' => {
    'lastUpdated' => '1252338020',
    'message' => 'GUID des WYSIWIG-Editors mit dem der Berichtsinhalt bearbeitet wird.'
  },
  'rssUrl' => {
    'lastUpdated' => '1252338036',
    'message' => 'URL zum RSS-Feed dieses Berichtsarchivs'
  },
  'searchButton' => {
    'lastUpdated' => '1252338096',
    'message' => 'Button mit dem internationalisierten Bezeichner um eine Suchanfrage abzuschicken. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'searchFooter' => {
    'lastUpdated' => '1252338143',
    'message' => 'HTML-Endcode des Suchformulars. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'searchForm' => {
    'lastUpdated' => '1252338190',
    'message' => 'Textfeld in das der Nutzer Schlüsselworte für die Suche eingeben kann. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'searchHeader' => {
    'lastUpdated' => '1252338154',
    'message' => 'HTML-Startcode des Suchformulars. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'stories per page' => {
    'lastUpdated' => '1252338197',
    'message' => 'Berichte pro Seite'
  },
  'stories per page help' => {
    'lastUpdated' => '1252338272',
    'message' => 'Anzahl Berichte, die pro Seite angezeigt werden. Wenn das Asset als HTML exportiert wird entahlten die generierten Seiten standardmäßig 10 Berichte.'
  },
  'story template' => {
    'lastUpdated' => '1252338282',
    'message' => 'Berichtstemplate'
  },
  'story template help' => {
    'lastUpdated' => '1252338321',
    'message' => 'Template zur Anzeige von Berichtsassets aus diesem Berichtsarchiv'
  },
  'storyTemplateId' => {
    'lastUpdated' => '1252338352',
    'message' => 'GUID des Templates zur Anzeige des Berichtsassets'
  },
  'story_loop' => {
    'lastUpdated' => '1252338397',
    'message' => 'Eine Schleife, die alle Berichte enthält, die am vorgegebenen Tag im Epoch-Datum erstellt wurden.'
  },
  'storyarchive asset template variables title' => {
    'lastUpdated' => '1252338405',
    'message' => 'Story Archive Asset Template Variables. '
  },
  'template' => {
    'lastUpdated' => '1252338421',
    'message' => 'Berichtsarchiv Template'
  },
  'template help' => {
    'lastUpdated' => '1252338436',
    'message' => 'Template zur Anzeige des Berichtsarchivs'
  },
  'templateId' => {
    'lastUpdated' => '1252338458',
    'message' => 'GUID des Templates zur Anzeige des Berichtsarchivs.'
  },
  'title' => {
    'lastUpdated' => '1252338465',
    'message' => 'Titel des Berichts'
  },
  'url' => {
    'lastUpdated' => '1252338483',
    'message' => 'URL um einen Bericht anzuzeigen'
  },
  'view template' => {
    'lastUpdated' => '1252338503',
    'message' => 'Berichtarchiv Anzeigetemplate'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_StoryArchive.pm <==
package WebGUI::i18n::German::Asset_StoryArchive;
use utf8;
our $I18N = {
  'add a story' => {
    'lastUpdated' => '1252336742',
    'message' => 'Bericht hinzufügen'
  },
  'addStoryUrl' => {
    'lastUpdated' => '1252336767',
    'message' => 'URL mit dem der Benutzer einen Bericht hinzufügen kann'
  },
  'alphabetically' => {
    'lastUpdated' => '1281649062',
    'message' => 'Alphabetisch'
  },
  'approval workflow' => {
    'lastUpdated' => '1252336775',
    'message' => 'Story Approval Workflow'
  },
  'approval workflow help' => {
    'lastUpdated' => '1252336823',
    'message' => 'Wählen Sie einen Workflow, der auf jeden Bericht angewandt wird, wenn er gespeichert wird.'
  },
  'approvalWorkflowId' => {
    'lastUpdated' => '1252336857',
    'message' => 'Die GUID des Workflows, der auf jeden Bericht angewandt wird, wenn er gespeichert wird.'
  },
  'archive after' => {
    'lastUpdated' => '1252336868',
    'message' => 'Berichte archivieren nach'
  },
  'archive after help' => {
    'lastUpdated' => '1252336936',
    'message' => 'Nach dieser Zeit werden Berichtsassets archiviert und sind nicht mehr in der Berichtsliste oder den Feeds sichtbar. Die Archivierung kann mit 0 abgeschaltet werden.'
  },
  'archiveAfter' => {
    'lastUpdated' => '1252336972',
    'message' => 'Zeit in Sekunden. Nach dieser Zeit wird der Bericht archiviert. '
  },
  'asset title' => {
    'lastUpdated' => '1252336980',
    'message' => 'Titel des Assets'
  },
  'asset url' => {
    'lastUpdated' => '1252336987',
    'message' => 'URL des Assets'
  },
  'assetName' => {
    'lastUpdated' => '1250973574',
    'message' => 'Berichtsarchiv'
  },
  'asset_loop' => {
    'lastUpdated' => '1252337037',
    'message' => 'Schleife, die die ersten bis zu 50 Assets enthält, auf die das Schlüsselwort zutrifft.'
  },
  'atomUrl' => {
    'lastUpdated' => '1252337053',
    'message' => 'URL zum Atom-Feed für dieses Berichtsarchiv'
  },
  'canPostStories' => {
    'lastUpdated' => '1252337078',
    'message' => 'Ein boolscher Wert der wahr ist, wenn der Nutzer Berichte verfassen darf.'
  },
  'chronologically' => {
    'lastUpdated' => '1281649070',
    'message' => 'Chronologisch'
  },
  'creationDate' => {
    'lastUpdated' => '1252337119',
    'message' => 'Datum als Epochangabe, an dem der Bericht erstellt oder ins Berichtarchiv augenommen wurde.'
  },
  'date_loop' => {
    'lastUpdated' => '1252337184',
    'message' => 'Eine Schleife, die Berichte an ihren Erstellungsdatum enthält mit Unterschleifen für jeden Tag. Die Schleife hat Seitenumbrüche.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1252337234',
    'message' => 'Icon um den Bericht zu löschen. Hat der Nutzer keine Löschberechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'edit story template' => {
    'lastUpdated' => '1252337250',
    'message' => 'Template Bericht bearbeiten'
  },
  'edit story template help' => {
    'lastUpdated' => '1252337286',
    'message' => 'Template um ein Berichtsasset hinzuzufügen oder zu bearbeiten.'
  },
  'editIcon' => {
    'lastUpdated' => '1252337310',
    'message' => 'Icon um den Bericht zu bearbeiten. Hat der Nutzer keine Bearbeiten-Berechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'editStoryTemplateId' => {
    'lastUpdated' => '1252337364',
    'message' => 'GUID des Templates mit dem Berichtsassets hinzugefügt oder bearbeitet werden.'
  },
  'epochDate' => {
    'lastUpdated' => '1252337428',
    'message' => 'Epoch-Angabe für den Tagesbeginn des Tages an dem die Berichte dem Berichtsarchiv hinzugefügt wurden.'
  },
  'group to post' => {
    'lastUpdated' => '1252337445',
    'message' => 'Gruppe die verfasst'
  },
  'group to post help' => {
    'lastUpdated' => '1252337468',
    'message' => 'Gruppe die Berichte zu diesem Berichtsarchiv hinzufügen darf.'
  },
  'groupToPost' => {
    'lastUpdated' => '1252337493',
    'message' => 'GUID der Gruppe die Berichte zum Berichtsarchiv hinzufügen darf.'
  },
  'keyword' => {
    'lastUpdated' => '1252337511',
    'message' => 'Schlüsselwort dieser Assetliste'
  },
  'keyword list template' => {
    'lastUpdated' => '1252337539',
    'message' => 'Berichtsarchiv Template Schlüsselwortliste'
  },
  'keyword list template help' => {
    'lastUpdated' => '1252337612',
    'message' => 'Das Template um die Assetliste anzuzeigen, auf die ein Schlüsselwort zutrifft wenn das Berichtsarchiv exportiert wird.'
  },
  'keywordCloud' => {
    'lastUpdated' => '1252337648',
    'message' => 'Die Tag-Wolke der Schlüsselworte in diesem Berichtsarchiv'
  },
  'keywordListTemplateId' => {
    'lastUpdated' => '1252337748',
    'message' => 'GUID des Templates um die Assetliste anzuzeigen, auf die ein Schlüsselwort zutrifft wenn das Berichtsarchiv exportiert wird.'
  },
  'photo width' => {
    'lastUpdated' => '1252337759',
    'message' => 'Photobreite'
  },
  'photo width help' => {
    'lastUpdated' => '1252337953',
    'message' => 'Photos die vom YUI Carousel angezeigt werden müssen für eine korrekte Darstellung die selbe Größe haben. Auf diese Breite werden alle Photos skaliert. Um dieses Feature auszuschalten die Breite auf 0 setzen.'
  },
  'photoWidth' => {
    'lastUpdated' => '1252337842',
    'message' => 'Die Breite auf die alle Photos, die zu Berichten in diesem Berichtsarchiv hochgeladen werden, skaliert werden'
  },
  'rich editor' => {
    'lastUpdated' => '1252337959',
    'message' => 'Rich Editor'
  },
  'rich editor help' => {
    'lastUpdated' => '1252337987',
    'message' => 'Der WYSIWIG-Editor mit dem der Berichtsinhalt bearbeitet wird.'
  },
  'richEditorId' => {
    'lastUpdated' => '1252338020',
    'message' => 'GUID des WYSIWIG-Editors mit dem der Berichtsinhalt bearbeitet wird.'
  },
  'rssUrl' => {
    'lastUpdated' => '1252338036',
    'message' => 'URL zum RSS-Feed dieses Berichtsarchivs'
  },
  'searchButton' => {
    'lastUpdated' => '1252338096',
    'message' => 'Button mit dem internationalisierten Bezeichner um eine Suchanfrage abzuschicken. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'searchFooter' => {
    'lastUpdated' => '1252338143',
    'message' => 'HTML-Endcode des Suchformulars. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'searchForm' => {
    'lastUpdated' => '1252338190',
    'message' => 'Textfeld in das der Nutzer Schlüsselworte für die Suche eingeben kann. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'searchHeader' => {
    'lastUpdated' => '1252338154',
    'message' => 'HTML-Startcode des Suchformulars. Diese Variable ist leer, wenn das Berichtsarchiv als HTML exportiert wird.'
  },
  'sortAlphabeticallyChronologically' => {
    'lastUpdated' => '1281649090',
    'message' => 'Sortierreihenfolge'
  },
  'sortAlphabeticallyChronologically description' => {
    'lastUpdated' => '1281649168',
    'message' => 'Legt fest, ob Meldungen nach Veröffentlichungsdatum oder alphabetisch nach Titel sortiert werden.'
  },
  'stories per page' => {
    'lastUpdated' => '1252338197',
    'message' => 'Berichte pro Seite'
  },
  'stories per page help' => {
    'lastUpdated' => '1252338272',
    'message' => 'Anzahl Berichte, die pro Seite angezeigt werden. Wenn das Asset als HTML exportiert wird entahlten die generierten Seiten standardmäßig 10 Berichte.'
  },
  'story template' => {
    'lastUpdated' => '1252338282',
    'message' => 'Berichtstemplate'
  },
  'story template help' => {
    'lastUpdated' => '1252338321',
    'message' => 'Template zur Anzeige von Berichtsassets aus diesem Berichtsarchiv'
  },
  'storyTemplateId' => {
    'lastUpdated' => '1252338352',
    'message' => 'GUID des Templates zur Anzeige des Berichtsassets'
  },
  'story_loop' => {
    'lastUpdated' => '1252338397',
    'message' => 'Eine Schleife, die alle Berichte enthält, die am vorgegebenen Tag im Epoch-Datum erstellt wurden.'
  },
  'storyarchive asset template variables title' => {
    'lastUpdated' => '1252338405',
    'message' => 'Story Archive Asset Template Variables. '
  },
  'template' => {
    'lastUpdated' => '1252338421',
    'message' => 'Berichtsarchiv Template'
  },
  'template help' => {
    'lastUpdated' => '1252338436',
    'message' => 'Template zur Anzeige des Berichtsarchivs'
  },
  'templateId' => {
    'lastUpdated' => '1252338458',
    'message' => 'GUID des Templates zur Anzeige des Berichtsarchivs.'
  },
  'title' => {
    'lastUpdated' => '1252338465',
    'message' => 'Titel des Berichts'
  },
  'url' => {
    'lastUpdated' => '1252338483',
    'message' => 'URL um einen Bericht anzuzeigen'
  },
  'view template' => {
    'lastUpdated' => '1252338503',
    'message' => 'Berichtarchiv Anzeigetemplate'
  }
}
;

1;
